@@ -52,7 +52,7 @@ impl Deref for Bytes<'_> {
     type Target = [u8];
 
     fn deref(&self) -> &Self::Target {
-        &self.0
+        self.0
     }
 }
 
@@ -131,9 +131,6 @@ impl fmt::Display for Error {
     }
 }
 
-#[cfg(any(test, feature = "std"))]
-impl std::error::Error for Error {}
-
 pub(crate) struct Serializer<'a, const B: usize> {
     buf: Vec<u8, B>,
     cmd: &'a str,
@@ -319,7 +316,7 @@ impl<'a, 'b, const B: usize> ser::Serializer for &'a mut Serializer<'b, B> {
 
         // Temporary storage for encoded a single char.
         // A char is up to 4 bytes long wehn encoded to UTF-8.
-        let mut encoding_tmp = [0u8; 4];
+        let mut encoding_tmp = [0_u8; 4];
 
         for c in v.chars() {
             match c {
@@ -524,6 +521,8 @@ impl ser::Error for Error {
     }
 }
 
+impl ser::StdError for Error {}
+
 #[allow(clippy::empty_enum)]
 pub(crate) enum Unreachable {}
 
